;==================================================================
;==================================================================
PRO ARIES_DATA_PLOT_141014,make_ps=make_ps
;==================================================================
;Reads in ARIES data for one flight
;Selects data for a run within a flight
;Converts radiance to brightness temperature
;Plots brightness temperature vs wavenumber
;==================================================================
;Define directory where plots will be saved:
ps_dir='/export/cloud/aerosol/jp902366/fennec/rad_meas/aries/b709/141014_ugproj/'

;Define directory where ARIES data is stored:
dir='/export/cloud/aerosol/jp902366/fennec/data/aries/f4_2012/'

;Define filename containing ARIES data:
fname='metoffice-aries_faam_20120617_r0_b709_mct.nc'

;Create full path name of data file and directory
filename=dir+fname

;------------------------------------------
;Read in data from ARIES file
;------------------------------------------
;Open data file
NC_OPEN,filename,ncid
;Read in scan direction values
NC_RETRIEVE_VARIABLE,ncid,'SCANDIR',scandir
;Read in time (seconds since midnight)
NC_RETRIEVE_VARIABLE,ncid,'SECONDS',ssm
;Read in wavenumber, in cm-1
NC_RETRIEVE_VARIABLE,ncid,'WAVENUM',wavenum  ;cm-1

;Read in ARIES radiance
;Data read in is for the whole flight
;Info on ARIES data from datafile:
;SPECTRAL_RADIANCE_[W/(m2*sr*1/cm)] = W m-2 cm sr-1
;ariesrad(scandir,ssm,wavenum)
NC_RETRIEVE_VARIABLE,ncid,'ARIESRAD',ariesrad_wavenum   

;Close data file now all variables required are read in
NC_CLOSE,ncid

;------------------------------------------
;Do some processing on the data read in:
;------------------------------------------
;Calculate number of wavelengths (no. wavenumbers)
n_wavenum=N_ELEMENTS(wavenum)
;Calculate number of times
n_ssm=N_ELEMENTS(ssm)
;Calculate number of scan directions
n_scandir=N_ELEMENTS(scandir)

;Convert from wavenumber (in cm-1) to wavelength (microns)
wavelen_um=(1./wavenum)*1.e4
;Convert from wavelength (microns) to wavelength (metres)
wavelen_metres=wavelen_um*1e-6
;Calculate wavelength in metres
wavenum_metres=1.0/wavelen_metres

;------------------------------------------
;Select measurements which fall within the times for Run 2
;------------------------------------------
;Define time in seconds since midnight for start of run 2
;R2 (high level)
;r2_start=134924
CONVERT_HRMINSEC_TO_SECSINCEMIDNIGHT,13,49,24,r2_ssm_start
;Define time in seconds since midnight for end of run 2
;r2_end=140423
CONVERT_HRMINSEC_TO_SECSINCEMIDNIGHT,14,4,23,r2_ssm_end
;define indices which relate to r2 times
;count_r2 is the number of datapoints in R2
r2_index=where(ssm ge r2_ssm_start AND ssm le r2_ssm_end,count_r2)
;select aries data within r2 times
ariesrad_wavenum_r2=ariesrad_wavenum (*,r2_index,*)


;---------------------------------------
;quick plot of actual radiances at 1 time
;---------------------------------------
;setup plot window
SETUP_WINDOW_COL
;setup plot for 2 graphs
!p.multi=[0,1,2]

;Make a plot of 2 graphs:
;1) plot radiance against wavelength
plot,wavelen_um,ariesrad_wavenum_r2(0,500,*),$
	xtitle='Wavelength, um',ytitle=textoidl('B_{\nu}, Wm^{-2}sr^{-1}cm')

;2) plot radiance against wavenumber
plot,wavenum,ariesrad_wavenum_r2(0,500,*),xrange=[600,1800],$
	xtitle='Wavenumber, cm-1',ytitle=textoidl('B_{\nu}, Wm^{-2}sr^{-1}cm')


;---------------------------------------
;Calculate brightness temperatures from radiance for R2
;---------------------------------------
;R2
;convert aries radiance (wavenumber format) from (cm-1)-1 to (m-1)-1
ariesrad_wavenum_r2_metres=ariesrad_wavenum_r2*0.01
;Call separate module to calculate brightness temperature from radiance:
;TB_R2 is brightness temperature for R2
CONVERT_RADIANCE_WAVENUM_TO_BRIGHTNESS_TEMPERATURE_141014,n_scandir,count_r2,n_wavenum,wavenum_metres,ariesrad_wavenum_r2_metres,TB_R2


;---------------------------------------
;average TB over run
;---------------------------------------
TB_R2_mean=TOTAL(TB_R2,2)/FLOAT(count_r2)

;---------------------------------------
;Plot of wavenum vs brightness temperature
;---------------------------------------
;Setup plot - either to screen, or to file (call with /make_ps)
IF keyword_set(make_ps) THEN BEGIN
   ;define name of output file
    ps_name='my_plot_name.ps'
    SETUP_PS_COL,ps_name,ps_dir
ENDIF ELSE BEGIN
  SETUP_WINDOW_COL
ENDELSE

;Make the plot
plot,wavenum,tb_r2_mean(0,*),$
	xrange=[600,1800],yrange=[200,350],$
	xtitle=textoidl('Wavenumber, cm^{-1}'),$
	ytitle='Brightness Temperature, K',$
	title='ARIES Brightness Temperatures for b709 R2'

;plot another line on the plot
oplot,wavenum,tb_r2_mean(0,*),col=1

;write the legend
;legend
x1=0.4
y1=0.3
xyouts,x1,y1,'R2, high level',/normal,col=1

IF keyword_set(make_ps) THEN CLOSE_PS

stop

;END OF PROGRAM----------------------
END