;===================================================================
;===================================================================
PRO CONVERT_RADIANCE_WAVENUM_TO_BRIGHTNESS_TEMPERATURE_141014,$
;input:    
	   n_scandir,$
	   n_data,$
	   n_wavenum,$
	   wavenum,$
	   radiance_wavenum,$
;output:
	brightness_temperature
;===================================================================
;converts radiance in wavenumber format to brightness temperature
;Radiance must be in W m-2 sr-1 (m-1)-1 - i.e. in per wavenumber
;wavenumber (nu) must be in m-1
;brightness temperature output is in K
;It is assumed that the radiance array has dimensions as in ARIES data: (scandir, ssm, wavenumber)
;===================================================================

;Constants
h=6.626e-34  ;plank's constant
c=2.998e8    ;speed of light
kb=1.381e-23  ;stefan boltzman constant

;reform wavenum array to be the same size as radiance array:
wavenum_reformed=REBIN(REFORM(wavenum,1,1,n_wavenum),n_scandir,n_data,n_wavenum)


;Calculate brightness temperature in 3 steps:

hcnu=h*c*wavenum_reformed

twohcsqnucubed=2.0*h*(c^2.0)*((wavenum_reformed)^3.0)

brightness_temperature=hcnu/(kb*(ALOG((twohcsqnucubed/radiance_wavenum)+1.0)))


END
